@@ -1,6 +1,6 @@
 from .config import get_config_all, get_config_regression, get_config_tune, get_citations
 from .run import MMSA_run, SUPPORTED_DATASETS, SUPPORTED_MODELS
 try:
-    from .run import SENA_run
+    from .run import SENA_run, DEMO_run
 except ImportError:
     pass
\ No newline at end of file
